_BASE_URL_ = 'https://www.cnbc.com'
_HEADERS_ = {
    'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,',
    'Accept-Encoding': 'gzip, deflate, br',
    'DNT': '1',
    'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/126.0.0.0 Safari/537.36'
}

_NEWS_URI_ = {
    'latest': 'latest/',
    'trending': 'trending/',
    'economy': 'economy/',
    'jobs': 'jobs/',
    'white-house': 'white-house/',
    'hospitals': 'hospitals/',
    'transportation': 'transportation/',
    'media': 'media/',
    'internet': 'internet/',
    'congress': 'congress/',
    'policy': 'policy/',
    'finance': 'finance/',
    'life': 'life/',
    'defense': 'defense/',
    'europe-politics': 'europe-politics/',
    'china-politics': 'china-politics/',
    'asia-politics': 'asia-politics/',
    'world-politics': 'world-politics/',
    'equity-opportunity': 'equity-opportunity/',
    'politics': 'politics/',
    'wealth': 'wealth/',
    'world-economy': 'world-economy/',
    'central-banks': 'central-banks/',
    'real-estate': 'real-estate/',
    'health-and-science': 'health-and-science/',
    'small-business': 'small-business/',
    'life-and-health-insurance': 'life-and-health-insurance/',
    'business': 'business/',
    'energy': 'energy/',
    'industrials': 'industrials/',
    'retail': 'retail/',
    'cybersecurity': 'cybersecurity/',
    'mobile': 'mobile/',
    'technology': 'technology/',
    'cnbc-disruptors': 'cnbc-disruptors/',
    'tech-guide': 'tech-guide/',
    'social-media': 'social-media/',
    'climate': 'climate/'
}

_MARKETS_URI_ = {
    'quote-summary': '/quotes/',
    'pre-markets': '',
    'us-markets': '',
    'europe-markets': '',
    'asia-markets': '',
    'currencies': '',
    'cryptocurrencies': '',
    'futures-and-commodities': '',
    'bonds': '',
    'funds-and-etfs': ''
}